summaryrefslogtreecommitdiffstats
path: root/ConfigureChecks.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'ConfigureChecks.cmake')
-rw-r--r--ConfigureChecks.cmake17
1 files changed, 7 insertions, 10 deletions
diff --git a/ConfigureChecks.cmake b/ConfigureChecks.cmake
index a2d6593a..0e0d3958 100644
--- a/ConfigureChecks.cmake
+++ b/ConfigureChecks.cmake
@@ -35,19 +35,16 @@ if( BUILD_DOC AND BUILD_KIG )
endif( )
##### check for arts
if( WITH_ARTS )
- pkg_search_module( ARTS arts )
- if( NOT ARTS_FOUND )
- tde_message_fatal( "aRts is requested but was not found on your system" )
- endif( NOT ARTS_FOUND )
- set( WITHOUT_ARTS false )
-endif( WITH_ARTS )
-
-if( NOT WITH_ARTS )
+ if( NOT TARGET artskde-shared )
+ tde_message_fatal( "aRts support through tdelibs is requested but was not found on your system" )
+ endif()
+ set( ARTSKDE_LIBRARIES artskde-shared )
+ else()
set( WITHOUT_ARTS 1 )
-endif( NOT WITH_ARTS )
+endif()
##### check for boost
@@ -35,19 +35,16 @@ if( BUILD_DOC AND BUILD_KIG )
endif( )
-##### check for arts
+##### check for arts support
if( WITH_ARTS )